# Changelog

All notable changes to Sparvi Core will be documented in this file.

## [0.4.2] - 2025-03-05
### Fixed
- Fixed profile_table queries

## [0.4.1] - 2025-03-04
### Fixed
- Fixed URL in documentation

### Changed
- Updated profile engine to default to no row level samples returned

## [0.4.0] - 2025-03-04
### Added
- Initial release of Sparvi Core package
- CLI for profile and validation commands
- Profile engine for data profiling
- Validation framework with default rules